@@ -1,10 +1,16 @@
 # -*- coding: utf-8 -*-
 from plone.app.linkintegrity.handlers import referencedRelationship
 from plone.app.uuid.utils import uuidToObject
-from Products.Archetypes.config import REFERENCE_CATALOG
+try:
+    from Products.Archetypes.config import REFERENCE_CATALOG
+except ImportError:
+    REFERENCE_CATALOG = "reference_catalog"
 from Products.CMFCore.utils import getToolByName
 from zope.lifecycleevent import modified
 
+import logging
+log = logging.getLogger(__name__)
+
 
 def migrate_linkintegrity_relations(context):
     """Migrate linkintegrity-relation from reference_catalog to zc.relation.
@@ -17,6 +23,10 @@ def migrate_linkintegrity_relations(context):
                 continue
             source_obj = uuidToObject(brain.sourceUID)
             target_obj = uuidToObject(brain.targetUID)
+            if source_obj is None or target_obj is None:
+                # reference_catalog may be inconsistent
+                log.info('Cannot delete relation since the relation_catalog is inconsistent.')   # noqa: E501
+                continue
             # Delete old reference
             reference_catalog.deleteReference(
                 source_obj, target_obj, relationship=referencedRelationship)
